@@ -3,8 +3,9 @@ Main interface for dynamodb service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dynamodb import (
+    from mypy_boto3_dynamodb import (
         Client,
         DynamoDBClient,
         DynamoDBServiceResource,
@@ -16,7 +17,7 @@ Usage::
         ServiceResource,
         TableExistsWaiter,
         TableNotExistsWaiter,
-        )
+    )
 
     session = boto3.Session()
 
@@ -34,6 +35,7 @@ Usage::
     list_tags_of_resource_paginator: ListTagsOfResourcePaginator = client.get_paginator("list_tags_of_resource")
     query_paginator: QueryPaginator = client.get_paginator("query")
     scan_paginator: ScanPaginator = client.get_paginator("scan")
+    ```
 """
 from mypy_boto3_dynamodb.client import DynamoDBClient as Client, DynamoDBClient
 from mypy_boto3_dynamodb.paginator import (
