@@ -3,13 +3,15 @@ Main interface for dynamodb service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dynamodb import DynamoDBClient
+    from mypy_boto3_dynamodb import DynamoDBClient
 
     session = boto3.Session()
 
     client: DynamoDBClient = boto3.client("dynamodb")
     session_client: DynamoDBClient = session.client("dynamodb")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
