@@ -3,8 +3,11 @@ Main interface for dynamodb service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dynamodb import (
+
+    from mypy_boto3_dynamodb import DynamoDBClient
+    from mypy_boto3_dynamodb import (
         ListBackupsPaginator,
         ListTablesPaginator,
         ListTagsOfResourcePaginator,
@@ -19,6 +22,7 @@ Usage::
     list_tags_of_resource_paginator: ListTagsOfResourcePaginator = client.get_paginator("list_tags_of_resource")
     query_paginator: QueryPaginator = client.get_paginator("query")
     scan_paginator: ScanPaginator = client.get_paginator("scan")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
