@@ -3,15 +3,19 @@ Main interface for dynamodb service ServiceResource
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dynamodb import DynamoDBServiceResource
-    import mypy_boto3.dynamodb.service_resource as dynamodb_resources
+
+    from mypy_boto3_dynamodb import DynamoDBServiceResource
+    import mypy_boto3_dynamodb.service_resource as dynamodb_resources
 
     resource: DynamoDBServiceResource = boto3.resource("dynamodb")
     session_resource: DynamoDBServiceResource = session.resource("dynamodb")
 
     Table: dynamodb_resources.Table = resource.Table(...)
+
     ...
+```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
