@@ -3,8 +3,11 @@ Main interface for dynamodb service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.dynamodb import (
+
+    from mypy_boto3_dynamodb import DynamoDBClient
+    from mypy_boto3_dynamodb import (
         TableExistsWaiter,
         TableNotExistsWaiter,
     )
@@ -13,6 +16,7 @@ Usage::
 
     table_exists_waiter: TableExistsWaiter = client.get_waiter("table_exists")
     table_not_exists_waiter: TableNotExistsWaiter = client.get_waiter("table_not_exists")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import TYPE_CHECKING
